@@ -404,11 +404,11 @@ impl<E> EventDecoder<E> for ZstdProtoDecoder
 
 }
 
-impl<T, E> EventDecoder<E> for Fn(T) -> Result<E, Error>
+impl<E> EventDecoder<E> for Fn(Vec<u8>) -> Result<E, Error>
     where E: for<'a> Deserialize<'a>
 {
     fn decode(&mut self, body: Vec<u8>) -> Result<E, Error> {
-        self.decode(body)
+        (self)(body)
     }
 }
 
